@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.008003;
 
-our $VERSION = '1.508';
+our $VERSION = '1.509';
 use Exporter 'import';
 our @EXPORT_OK = qw( choose );
 
@@ -72,7 +72,6 @@ sub __defaults {
         #no_spacebar => undef,
         order        => 1,
         pad          => 2,
-        #pad_one_row => pad,
         page         => 1,
         undef        => '<undef>',
     };
@@ -85,7 +84,6 @@ sub __undef_to_defaults {
     for my $option ( keys %$defaults ) {
         $self->{$option} = $defaults->{$option} if ! defined $self->{$option};
     }
-    $self->{pad_one_row}  = $self->{pad} if ! defined $self->{pad_one_row};
 }
 
 
@@ -106,7 +104,7 @@ sub __valid_options {
         max_width       => '[ 1-9 ][ 0-9 ]*',
         default         => '[ 0-9 ]+',
         pad             => '[ 0-9 ]+',
-        pad_one_row     => '[ 0-9 ]+',
+        pad_one_row     => '[ 0-9 ]+', # removed ###
         lf              => 'ARRAY',
         mark            => 'ARRAY',
         no_spacebar     => 'ARRAY',
@@ -225,6 +223,16 @@ sub __choose {
     if ( ! @$orig_list_ref ) {
         return;
     }
+
+    # ###
+    if ( defined $self->{pad_one_row} ) {
+        print 'Please remove the invalid option "pad_one_row" (see "Changes"/1.509).' . "\n";
+        print 'Continue with ENTER ';
+        my $p = <STDIN>;
+        print "\n";
+    }
+    # ###
+
     $self->{orig_list} = $orig_list_ref;
     local $\ = undef;
     local $, = undef;
@@ -756,18 +764,18 @@ sub __size_and_layout {
     else {
         $self->{avail_col_width} = $self->{length_longest};
     }
-    $self->{all_in_first_row} = '';
+    my $all_in_first_row = '';
     if ( $self->{layout} == 0 || $self->{layout} == 1 ) {
         for my $idx ( 0 .. $#{$self->{list}} ) {
-            $self->{all_in_first_row} .= $self->{list}[$idx];
-            $self->{all_in_first_row} .= ' ' x $self->{pad_one_row} if $idx < $#{$self->{list}};
-            if ( $self->__print_columns( $self->{all_in_first_row} ) > $self->{avail_width} ) {
-                $self->{all_in_first_row} = '';
+            $all_in_first_row .= $self->{list}[$idx];
+            $all_in_first_row .= ' ' x $self->{pad} if $idx < $#{$self->{list}};
+            if ( $self->__print_columns( $all_in_first_row ) > $self->{avail_width} ) {
+                $all_in_first_row = '';
                 last;
             }
         }
     }
-    if ( $self->{all_in_first_row} ) {
+    if ( $all_in_first_row ) {
         $self->{rc2idx}[0] = [ 0 .. $#{$self->{list}} ];
     }
     elsif ( $self->{layout} == 3 ) {
@@ -911,13 +919,12 @@ sub __wr_cell {
     my $is_current_pos = $row == $self->{pos}[ROW] && $col == $self->{pos}[COL];
     my $idx = $self->{rc2idx}[$row][$col];
     if ( $#{$self->{rc2idx}} == 0 && $#{$self->{rc2idx}[0]} > 0 ) {
-        my $pad = $self->{all_in_first_row} ? $self->{pad_one_row} : $self->{pad};
         my $lngth = 0;
         if ( $col > 0 ) {
             for my $cl ( 0 .. $col - 1 ) {
                 my $i = $self->{rc2idx}[$row][$cl];
                 $lngth += $self->__print_columns( $self->{list}[$i] );
-                $lngth += $pad;
+                $lngth += $self->{pad};
             }
         }
         $self->__goto( $row - $self->{p_begin}, $lngth );
@@ -1000,7 +1007,6 @@ sub __mouse_info_to_key {
     if ( $mouse_row > $#{$self->{rc2idx}} ) {
         return NEXT_get_key;
     }
-    my $pad = $self->{all_in_first_row} ? $self->{pad_one_row} : $self->{pad};
     my $matched_col;
     my $end_last_col = 0;
     my $row = $mouse_row + $self->{p_begin};
@@ -1009,13 +1015,13 @@ sub __mouse_info_to_key {
         my $end_this_col;
         if ( $#{$self->{rc2idx}} == 0 ) {
             my $idx = $self->{rc2idx}[$row][$col];
-            $end_this_col = $end_last_col + $self->__print_columns( $self->{list}[$idx] ) + $pad;
+            $end_this_col = $end_last_col + $self->__print_columns( $self->{list}[$idx] ) + $self->{pad};
         }
         else { #
             $end_this_col = $end_last_col + $self->{col_width};
         }
         if ( $col == 0 ) {
-            $end_this_col -= int( $pad / 2 );
+            $end_this_col -= int( $self->{pad} / 2 );
         }
         if ( $col == $#{$self->{rc2idx}[$row]} && $end_this_col > $self->{avail_width} ) {
             $end_this_col = $self->{avail_width};
@@ -1065,7 +1071,7 @@ Term::Choose - Choose items from a list interactively.
 
 =head1 VERSION
 
-Version 1.508
+Version 1.509
 
 =cut
 
@@ -1560,12 +1566,6 @@ Sets the number of whitespaces between columns. (default: 2)
 
 Allowed values: 0 or greater
 
-=head2 pad_one_row
-
-Sets the number of whitespaces between elements if we have only one row. (default: value of the option I<pad>)
-
-Allowed values: 0 or greater
-
 =head2 page
 
 0 - off
